
clear all
close all
clc

% -------------------------------- ToyData --------------------------------
params.alpha1  = (3.7e-3);
params.b1      = (0.8e-3);
params.lambda1 = 0.005;
params.sigmaX  = 0.001;

params.alpha   = (2.7e-3);
params.b       = (0.8e-3);
params.lambda  = 0.008;
params.sigmaY  = 0.001;

params.c       = 0.42;

inX = 0.84;
inY = 0.6;

[mu,theta,x,y,dataX,dataY] = toyData(params,inX,inY);
% -------------------------------------------------------------------------

times = 100:100:1000;
times = [0,times];

inCond.x    = inX;
inCond.y    = inY;
inCond.prob = 0.99;

fplus  = 1e-4;
fminus = 1e-4;

% ----------------------------- Initialisation ----------------------------
[aa,bb] = incip(times,inX,dataX,200,0.005);

paramPrior.alpha1  = 1/aa;
paramPrior.b1      = 1/bb;
paramPrior.lambda1 = 150;
paramPrior.sigma1  = 0.01;

[aa,bb] = incip(times,inY,dataY,200,0.005);

paramPrior.alpha   = 1/aa;
paramPrior.b       = 1/bb;
paramPrior.lambda  = 150;
paramPrior.sigma   = 0.01;

paramPrior.c       = 1/params.c;

paramPrior.gplus  = 1000*ones(1,length(dataX));
paramPrior.gminus = 1000*ones(1,length(dataX));
% -------------------------------------------------------------------------

Y = 400;              % number of iterations
g = 50;               % number of iterations after each plot

lrate = 0.0001;      % learning rate

[gplus,gtotal,gminus,finParams,finParams1,fplus,fminus,thet,monitorFreeEn]=swEM(dataX,dataY,times,paramPrior,fplus,fminus,inCond,lrate,Y,g);
%--------------------------------------------------------------------------

deltas = ones(1,length(gplus));
probs  = swProbs(gplus,gtotal,deltas,inCond.prob);

%Plot inferred posterior activity
figure, plot(mu), hold on, plot(probs,'r-.'), title('Master TF')
legend('input impulse','inferred posterior mean'), axis([0 1000 0 1.05])

%Plot posterior Theta
figure, plot(theta), hold on, plot(thet,'r-.'), axis([0 1000 0 1.05])
legend('theta','inferred theta'), title('Slave TF')

% Calculation of error bars
InitCond = inCond;
InitCond.x = 0;
InitCond.y = 0;
errX  = CalcErrBarsX(gplus,gminus,finParams1,finParams,InitCond,times);
ErrX = 2*sqrt(diag(errX)');
errY  = CalcErrBarsY(gplus,gminus,finParams1,finParams,InitCond,times);
ErrY = 2*sqrt(diag(errY)');

% Plot real, initialised and posterior values of parameters
figure, subplot(2,2,1)
M1(2,:) =([finParams.alpha finParams1.alpha]);
M1(1,:) =([params.alpha params.alpha1]);
M1(3,:) =([0 0]);
m = bar(M1'); legend('real','posterior')
hold on, errorbar([M1(2,1) M1(2,2)],[ErrY(1) ErrX(1)],'k.')
set(gca,'YMinorGrid','on'), title('Parameter \alpha (A, A_{1})')
subplot(2,2,2)
M2(2,:) =([finParams.b finParams1.b]);
M2(1,:) =([params.b params.b1]);
M2(3,:) =([0 0]);
m = bar(M2');
hold on, errorbar([M2(2,1) M2(2,2)],[ErrY(2) ErrX(2)],'k.')
set(gca,'YMinorGrid','on'), title('Parameter \beta (b, b_{1})')
subplot(2,2,3)
M3(2,:) =([finParams.c 0]);
M3(1,:) =([params.c 0]);
M3(3,:) =([0 0]);
m = bar(M3');
set(gca,'YMinorGrid','on'), title('Parameter c')
subplot(2,2,4)
M4(2,:) =([finParams.lambda finParams1.lambda]);
M4(1,:) =([params.lambda params.lambda1]);
M4(3,:) =([0 0]);
m = bar(M4');
set(gca,'YMinorGrid','on'), title('Parameter \lambda (\lambda, \lambda_{1})')

% Fitting
reDataX    = [inCond.x,dataX];
reDataY    = [inCond.y,dataY];
timesGrid  = [0:1000];
npts       = length(times);
[mom1X,RX,mom2X,kap] = momentsCalc(inCond,npts,times,finParams1,probs,gplus,gminus,params.c);
[mom1Y] = momentsCalcY(inCond,npts,times,finParams,finParams1,probs,gplus,gminus,mom1X,RX,mom2X,kap);
figure
subplot(1,2,1), plot(times,reDataX,'+'), title('x')
hold on, plot(timesGrid,mom1X,'r-.'), grid on
subplot(1,2,2), plot(times,reDataY,'+'), title('y')
hold on, plot(timesGrid,mom1Y,'r-.'), grid on
