function [gplus,gtotal,gminus,params]=swEMonlyX(dataX,times,paramPrior,fplus,fminus,inCond,Lrate,Y,gra,ngenes)

rand('seed',9082)
randn('seed',89201)

% --------- start with mean of prior --------------------------------------
params.alpha  = paramPrior.alpha1.^-1;
params.b      = paramPrior.b1.^-1;
params.lambda = paramPrior.lambda1.^-1;
params.sigma  = paramPrior.sigma1.^-1;
% -------------------------------------------------------------------------

reDataX    = [inCond.x' dataX];

EndT       = times(end)*100/times(2);
FalseTimes = times*100/times(2);
timesGrid  = 0:EndT;
npts       = length(FalseTimes);

% --------- Initialise transition rates gplus, gminus ---------------------
gplus  = ones(1,EndT).*0.001;
gminus = ones(1,EndT).*0.001;
gtotal = gplus+gminus;
% -------------------------------------------------------------------------

deltas2 = ones(1,length(gplus));
jj= 0;


while jj<=Y

    jj = jj+1;
    
    probs = swProbs(gplus,gtotal,deltas2,inCond.prob);
    
    % moments
    for i=1:ngenes
        paramsSingle.alpha  = params.alpha(i);
        paramsSingle.b      = params.b(i);
        paramsSingle.lambda = params.lambda(i);
        paramsSingle.sigma  = params.sigma(i);
        [mom1X(i,:),RX(i,:),mom2X(i,:)] = momentsCalc_x(inCond.x(i),npts,FalseTimes,paramsSingle,probs,gplus,gminus);
        clear paramsSingle
    end
    
    % multipliers
    deltaKx = 0.5*(params.sigma);
    deltaFx = -(params.sigma);
    
    for i=1:ngenes
        paramsSingle.alpha  = params.alpha(i);
        paramsSingle.b      = params.b(i);
        paramsSingle.lambda = params.lambda(i);
        paramsSingle.sigma  = params.sigma(i);
        [kappa(i,:),psi(i,:),fi(i,:)] = moltipCalc_x(gplus,gminus,deltaKx(i),deltaFx(i),reDataX(i,:),paramsSingle,FalseTimes,npts);
        clear paramsSingle
    end
    csi = csiCalc_x(psi,fi,gplus,gminus,fplus,fminus,params,FalseTimes,npts);

    [mom1X,RX,mom2X] = shortmoms_x(mom1X,RX,mom2X);
    
    kappa = kappa(:,2:end);
    psi   = psi(:,2:end);
    fi    = fi(:,2:end);   
    csi   = csi(2:end);
    
    % gradient wrt g
    gradG1 = (1-probs(2:end)).*log(gplus./fplus)  -   (1-probs(2:end)).*csi   + sum((RX-mom1X).*psi,1);
    gradG0 = probs(2:end).*log(gminus./fminus)    +     probs(2:end).*csi     +  sum(RX.*psi,1);
    gplus  = gplus  - Lrate*(gradG1);
    gminus = gminus - Lrate*(gradG0);
    
    for j=1:length(gplus)
        if gplus(j)<1e-6
            gplus(j)=1e-6;
        end
        if gplus(j)>1e-1
            gplus(j)=1e-1;
        end
        if gminus(j)<1e-6
            gminus(j)=1e-6;
        end
        if gminus(j)>1e-1
            gminus(j)=1e-1;
        end
    end
    
    gtotal = gplus+gminus;
    
    % gradient wrt parameters

    for i=1:ngenes
        gradA1 = - probs(2:end).*(fi(i,:)+psi(i,:)) - 2*RX(i,:).*kappa(i,:);
        gradB1 = - fi(i,:) -2*mom1X(i,:).*kappa(i,:) - probs(2:end).*psi(i,:);
        gradL1 = mom1X(i,:).*fi(i,:) + 2*mom2X(i,:).*kappa(i,:) + RX(i,:).*psi(i,:);
        
        params.alpha(i)  = params.alpha(i)  - (sum(gradA1))*10^(-round(log10(abs(sum(gradA1)))+5.0+...
            (round(log10(abs(sum(gradA1))))<3)*(3-round(log10(abs(sum(gradA1)))))));
        params.b(i)      = params.b(i)      - (sum(gradB1))*10^(-round(log10(abs(sum(gradB1)))+5.0+...
            (round(log10(abs(sum(gradB1))))<3)*(3-round(log10(abs(sum(gradB1)))))));
        params.lambda(i) = params.lambda(i) - (sum(gradL1))*10^(-round(log10(abs(sum(gradL1)))+5.0+...
            (round(log10(abs(sum(gradL1))))<3)*(3-round(log10(abs(sum(gradL1)))))));
    end
    
    % monitoring of variational free energy

    fprintf('%d of %d\n',jj,Y)
    
    clear mom1X mom2X RX kappa psi fi
    
    if mod(jj,gra)==0
        probs   = swProbs(gplus,gtotal,deltas2,inCond.prob);
        figure('Position',[40 90 1600 500])
        for i=1:ngenes
            paramsSingle.alpha  = params.alpha(i);
            paramsSingle.b      = params.b(i);
            paramsSingle.lambda = params.lambda(i);
            paramsSingle.sigma  = params.sigma(i);
            [mom1X(i,:),RX(i,:),mom2X(i,:)] = momentsCalc_x(inCond.x(i),npts,FalseTimes,paramsSingle,probs,gplus,gminus);
            clear paramsSingle
            
            subplot(1,ngenes,i), plot(timesGrid,interp1(FalseTimes,reDataX(i,:),[0:EndT]))
            hold on, plot(timesGrid,mom1X(i,:),'r-'), grid on
        end
        pause(0.5)
    end    
    
end